@@ -1,15 +1,17 @@
+from __future__ import annotations
+
 import abc
 import typing
 
 from lime_uow.resources import resource
 
-EntityType = typing.TypeVar("EntityType")
-
-
 __all__ = ("Repository",)
 
 
-class Repository(resource.Resource[None], abc.ABC, typing.Generic[EntityType]):
+EntityType = typing.TypeVar("EntityType")
+
+
+class Repository(resource.Resource[typing.Any], abc.ABC, typing.Generic[EntityType]):
     """Interface to access elements of a collection"""
 
     @abc.abstractmethod
@@ -32,6 +34,9 @@ class Repository(resource.Resource[None], abc.ABC, typing.Generic[EntityType]):
     def delete_all(self) -> None:
         raise NotImplementedError
 
+    def open(self) -> Repository[EntityType]:
+        return self
+
     @abc.abstractmethod
     def set_all(self, /, items: typing.Collection[EntityType]) -> typing.Collection[EntityType]:
         raise NotImplementedError
